==> tumbler-0.0.1.tgz: package/lib/tumbler.js <==
(function() {
  var Builder, BundleCompiler, Compiler, SimpleCompiler, TrivialCompiler, W_FILE, all, concatenate, extract_extension, fs, is_fresher, path, spawn;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  fs = require('fs');
  path = require('path');
  spawn = require('child_process').spawn;
  W_FILE = {
    flags: 'w',
    encoding: 'utf-8'
  };
  extract_extension = function(filepath) {
    var ext_match;
    ext_match = filepath.match(/(.*)\.([^\.]+)/);
    if (ext_match) {
      return {
        base: ext_match[1],
        ext: ext_match[2],
        filepath: filepath
      };
    } else {
      return {
        base: filepath,
        ext: null,
        filepath: filepath
      };
    }
  };
  is_fresher = function(src, dest) {
    /*
        src and dest must be existing
        filepaths.
        Returns true if src has been modified 
        more recently than dest.
        */    var dest_stat, src_stat;
    src_stat = fs.statSync(src);
    dest_stat = fs.statSync(dest);
    return src_stat.mtime > dest_stat.mtime;
  };
  Compiler = (function() {
    function Compiler() {}
    Compiler.prototype.match = function(dest) {};
    Compiler.prototype.get_source_list = function(dest) {};
    Compiler.prototype.build = function(dest, success, failure) {};
    return Compiler;
  })();
  all = function(predicate, els) {
    var el, _i, _len;
    for (_i = 0, _len = els.length; _i < _len; _i++) {
      el = els[_i];
      if (!(predicate(el))) {
        return false;
      }
    }
    return true;
  };
  SimpleCompiler = (function() {
    __extends(SimpleCompiler, Compiler);
    /*
        Compiler with 1-1 relationship between
        source files and dest files 
        and an explicit extension for both.
        */
    function SimpleCompiler(extSrc, extDest, command, command_args) {
      this.extSrc = extSrc;
      this.extDest = extDest;
      this.command = command;
      this.command_args = command_args != null ? command_args : [];
    }
    SimpleCompiler.prototype.match = function(dest) {
      var split;
      split = extract_extension(dest);
      return (split.ext === this.extDest) && (path.existsSync(this.get_source(dest)));
    };
    SimpleCompiler.prototype.get_source = function(dest) {
      var split;
      split = extract_extension(dest);
      return split.base + "." + this.extSrc;
    };
    SimpleCompiler.prototype.get_source_list = function(dest) {
      return [this.get_source(dest)];
    };
    SimpleCompiler.prototype.make_command = function(src) {
      var args;
      args = this.command_args.slice();
      args.push(src);
      return [this.command, args];
    };
    SimpleCompiler.prototype.build = function(dest, success, failure) {
      var child, cmd, dest_file, error_msg, src;
      src = this.get_source(dest);
      console.log("compiling " + src + " -> " + dest);
      cmd = this.make_command(src);
      dest_file = fs.createWriteStream(dest, W_FILE);
      child = spawn.apply(this, cmd);
      child.stdout.pipe(dest_file);
      error_msg = "";
      child.stderr.on("data", function(data) {
        return error_msg += data.toString();
      });
      return child.on("exit", function(code) {
        if (code === 0) {
          return success();
        } else {
          console.log("compilation failed");
          fs.unlink(dest);
          return failure(error_msg);
        }
      });
    };
    return SimpleCompiler;
  })();
  concatenate = function(sources, dest_file, success, failure) {
    var f, head, tail;
    if (sources.length === 0) {
      return success();
    } else {
      try {
        head = sources[0];
        tail = sources.slice(1);
        console.log(head);
        f = fs.createReadStream(head);
        f.on("end", function() {
          return concatenate(tail, dest_file, success, failure);
        });
        return f.pipe(dest_file);
      } catch (err) {
        return failure("Bundle failure!");
      }
    }
  };
  BundleCompiler = (function() {
    __extends(BundleCompiler, Compiler);
    /*
        Compiler with 1-1 relationship between
        source files and dest files 
        and an explicit extension for both.
        */
    function BundleCompiler() {}
    BundleCompiler.prototype.match = function(dest) {
      var source;
      source = this.get_bundle_detail_file(dest);
      return path.existsSync(source);
    };
    BundleCompiler.prototype.get_bundle_detail_file = function(dest) {
      return dest + ".bundle";
    };
    BundleCompiler.prototype.get_source_list = function(dest) {
      var bundle_detail, bundle_detail_data, bundle_detail_file, root, source, sources;
      root = path.dirname(dest);
      bundle_detail_file = this.get_bundle_detail_file(dest);
      bundle_detail_data = (fs.readFileSync(bundle_detail_file, 'utf-8')).toString();
      bundle_detail = JSON.parse(bundle_detail_data);
      sources = (function() {
        var _i, _len, _ref, _results;
        _ref = bundle_detail.sources;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          source = _ref[_i];
          _results.push(path.join(root, source));
        }
        return _results;
      })();
      return sources;
    };
    BundleCompiler.prototype.make_command = function(src) {
      var args;
      args = this.command_args.slice();
      args.push(src);
      return [this.command, args];
    };
    BundleCompiler.prototype.build = function(dest, success, failure) {
      var dest_file, sources;
      sources = this.get_source_list(dest);
      console.log(dest, " via concatenating:");
      dest_file = fs.createWriteStream(dest, W_FILE);
      return concatenate(sources, dest_file, success, failure);
    };
    return BundleCompiler;
  })();
  TrivialCompiler = (function() {
    __extends(TrivialCompiler, Compiler);
    function TrivialCompiler() {
      TrivialCompiler.__super__.constructor.apply(this, arguments);
    }
    TrivialCompiler.prototype.match = function(dest) {
      return true;
    };
    TrivialCompiler.prototype.get_source_list = function(dest) {
      return [];
    };
    TrivialCompiler.prototype.build = function(dest, success, failure) {
      if (path.existsSync(dest)) {
        return success();
      } else {
        return failure("File not found.");
      }
    };
    return TrivialCompiler;
  })();
  Builder = (function() {
    function Builder() {
      this.compilers = [];
    }
    Builder.prototype.register_compiler = function(compiler) {
      return this.compilers.push(compiler);
    };
    Builder.prototype.buildAll = function(dests, success, failure) {
      var dest;
      if (dests.length === 0) {
        return success();
      } else {
        dest = dests.pop();
        return this.build(dest, (__bind(function() {
          return this.buildAll(dests, success, failure);
        }, this)), failure);
      }
    };
    Builder.prototype._build_with_compiler = function(compiler, dest, success, failure) {
      var sources, sources_are_ready;
      sources = compiler.get_source_list(dest);
      sources_are_ready = function() {
        var older_than_dest;
        older_than_dest = function(src) {
          return is_fresher(dest, src);
        };
        if ((!path.existsSync(dest)) || all(older_than_dest, sources)) {
          return compiler.build(dest, success, failure);
        } else {
          return success();
        }
      };
      return this.buildAll(sources, sources_are_ready, failure);
    };
    Builder.prototype.build = function(dest, success, failure) {
      /*
              build destination when required
              */      var compiler, _i, _len, _ref;
      _ref = this.compilers;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        compiler = _ref[_i];
        if (compiler.match(dest)) {
          this._build_with_compiler(compiler, dest, success, failure);
          return;
        }
      }
      return failure({
        msg: "couldn't find any compiler"
      });
    };
    return Builder;
  })();
  exports.Compiler = Compiler;
  exports.BundleCompiler = BundleCompiler;
  exports.SimpleCompiler = SimpleCompiler;
  exports.TrivialCompiler = TrivialCompiler;
  exports.Builder = Builder;
}).call(this);

==> tumbler-0.0.2.tgz: package/lib/tumbler.js <==
(function() {
  var Builder, BundleCompiler, Compiler, SimpleCompiler, TrivialCompiler, W_FILE, all, concatenate, extract_extension, fs, is_fresher, path, spawn;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  }, __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  fs = require('fs');
  path = require('path');
  spawn = require('child_process').spawn;
  W_FILE = {
    flags: 'w',
    encoding: 'utf-8'
  };
  extract_extension = function(filepath) {
    var ext_match;
    console.log(filepath);
    ext_match = filepath.match(/(.*)\.([^\.]+)/);
    if (ext_match) {
      return {
        base: ext_match[1],
        ext: ext_match[2],
        filepath: filepath
      };
    } else {
      return {
        base: filepath,
        ext: null,
        filepath: filepath
      };
    }
  };
  is_fresher = function(src, dest) {
    /*
        src and dest must be existing
        filepaths.
        Returns true if src has been modified 
        more recently than dest.
        */
    var dest_stat, src_stat;
    src_stat = fs.statSync(src);
    dest_stat = fs.statSync(dest);
    return src_stat.mtime > dest_stat.mtime;
  };
  Compiler = (function() {
    function Compiler() {}
    Compiler.prototype.match = function(dest) {};
    Compiler.prototype.get_source_list = function(dest) {};
    Compiler.prototype.build = function(dest, success, failure) {};
    return Compiler;
  })();
  all = function(predicate, els) {
    var el, _i, _len;
    for (_i = 0, _len = els.length; _i < _len; _i++) {
      el = els[_i];
      if (!(predicate(el))) {
        return false;
      }
    }
    return true;
  };
  SimpleCompiler = (function() {
    __extends(SimpleCompiler, Compiler);
    /*
        Compiler with 1-1 relationship between
        source files and dest files 
        and an explicit extension for both.
        */
    function SimpleCompiler(extSrc, extDest, command, command_args) {
      this.extSrc = extSrc;
      this.extDest = extDest;
      this.command = command;
      this.command_args = command_args != null ? command_args : [];
    }
    SimpleCompiler.prototype.match = function(dest) {
      var split;
      split = extract_extension(dest);
      return (split.ext === this.extDest) && (path.existsSync(this.get_source(dest)));
    };
    SimpleCompiler.prototype.get_source = function(dest) {
      var split;
      split = extract_extension(dest);
      return split.base + "." + this.extSrc;
    };
    SimpleCompiler.prototype.get_source_list = function(dest) {
      return [this.get_source(dest)];
    };
    SimpleCompiler.prototype.make_command = function(src) {
      var args;
      args = this.command_args.slice();
      args.push(src);
      return [this.command, args];
    };
    SimpleCompiler.prototype.build = function(dest, success, failure) {
      var child, cmd, dest_file, error_msg, src;
      src = this.get_source(dest);
      console.log("compiling " + src + " -> " + dest);
      cmd = this.make_command(src);
      dest_file = fs.createWriteStream(dest, W_FILE);
      child = spawn.apply(this, cmd);
      child.stdout.pipe(dest_file);
      error_msg = "";
      child.stderr.on("data", function(data) {
        return error_msg += data.toString();
      });
      return child.on("exit", function(code) {
        if (code === 0) {
          return success();
        } else {
          console.log("compilation failed");
          fs.unlink(dest);
          return failure(error_msg);
        }
      });
    };
    return SimpleCompiler;
  })();
  concatenate = function(sources, dest_file, success, failure) {
    var f, head, tail;
    if (sources.length === 0) {
      return success();
    } else {
      try {
        head = sources[0];
        tail = sources.slice(1);
        console.log(head);
        f = fs.createReadStream(head);
        f.on("end", function() {
          return concatenate(tail, dest_file, success, failure);
        });
        return f.pipe(dest_file);
      } catch (err) {
        return failure("Bundle failure!");
      }
    }
  };
  BundleCompiler = (function() {
    __extends(BundleCompiler, Compiler);
    /*
        Compiler with 1-1 relationship between
        source files and dest files 
        and an explicit extension for both.
        */
    function BundleCompiler() {}
    BundleCompiler.prototype.match = function(dest) {
      var source;
      source = this.get_bundle_detail_file(dest);
      return path.existsSync(source);
    };
    BundleCompiler.prototype.get_bundle_detail_file = function(dest) {
      return dest + ".bundle";
    };
    BundleCompiler.prototype.get_source_list = function(dest) {
      var bundle_detail, bundle_detail_data, bundle_detail_file, root, source, sources;
      root = path.dirname(dest);
      bundle_detail_file = this.get_bundle_detail_file(dest);
      bundle_detail_data = (fs.readFileSync(bundle_detail_file, 'utf-8')).toString();
      bundle_detail = JSON.parse(bundle_detail_data);
      sources = (function() {
        var _i, _len, _ref, _results;
        _ref = bundle_detail.sources;
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          source = _ref[_i];
          _results.push(path.join(root, source));
        }
        return _results;
      })();
      return sources;
    };
    BundleCompiler.prototype.make_command = function(src) {
      var args;
      args = this.command_args.slice();
      args.push(src);
      return [this.command, args];
    };
    BundleCompiler.prototype.build = function(dest, success, failure) {
      var dest_file, sources;
      sources = this.get_source_list(dest);
      console.log(dest, " via concatenating:");
      dest_file = fs.createWriteStream(dest, W_FILE);
      return concatenate(sources, dest_file, success, failure);
    };
    return BundleCompiler;
  })();
  TrivialCompiler = (function() {
    __extends(TrivialCompiler, Compiler);
    function TrivialCompiler() {
      TrivialCompiler.__super__.constructor.apply(this, arguments);
    }
    TrivialCompiler.prototype.match = function(dest) {
      return true;
    };
    TrivialCompiler.prototype.get_source_list = function(dest) {
      return [];
    };
    TrivialCompiler.prototype.build = function(dest, success, failure) {
      if (path.existsSync(dest)) {
        return success();
      } else {
        return failure("File not found.");
      }
    };
    return TrivialCompiler;
  })();
  Builder = (function() {
    function Builder() {
      this.compilers = [];
    }
    Builder.prototype.register_compiler = function(compiler) {
      return this.compilers.push(compiler);
    };
    Builder.prototype.buildAll = function(dests, success, failure) {
      var dest;
      if (dests.length === 0) {
        return success();
      } else {
        dest = dests.pop();
        return this.build(dest, (__bind(function() {
          return this.buildAll(dests, success, failure);
        }, this)), failure);
      }
    };
    Builder.prototype._build_with_compiler = function(compiler, dest, success, failure) {
      var sources, sources_are_ready;
      sources = compiler.get_source_list(dest);
      sources_are_ready = function() {
        var older_than_dest;
        older_than_dest = function(src) {
          return is_fresher(dest, src);
        };
        if ((!path.existsSync(dest)) || all(older_than_dest, sources)) {
          return compiler.build(dest, success, failure);
        } else {
          return success();
        }
      };
      return this.buildAll(sources, sources_are_ready, failure);
    };
    Builder.prototype.build = function(dest, success, failure) {
      /*
              build destination when required
              */
      var compiler, _i, _len, _ref;
      _ref = this.compilers;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        compiler = _ref[_i];
        if (compiler.match(dest)) {
          this._build_with_compiler(compiler, dest, success, failure);
          return;
        }
      }
      return failure({
        msg: "couldn't find any compiler"
      });
    };
    return Builder;
  })();
  exports.Compiler = Compiler;
  exports.BundleCompiler = BundleCompiler;
  exports.SimpleCompiler = SimpleCompiler;
  exports.TrivialCompiler = TrivialCompiler;
  exports.Builder = Builder;
}).call(this);
